Name: libarchive
Version: 3.3.1
Release: 1
License: BSD
Summary: Multi-format archive and compression library
Url: https://www.libarchive.org

Source0: https://www.libarchive.org/downloads/libarchive-%{version}.tar.gz


%define reconf 0

%if %{reconf}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
%endif

BuildRequires: openssl-devel < 1.1.0
BuildRequires: zlib-devel
BuildRequires: libxml2-devel

%description
Multi-format archive and compression library

The source distribution includes the libarchive library, the bsdtar and bsdcpio command-line programs, full test suite, and documentation: 



%package -n libarchive13
Summary: libarchive library
Provides: %{name} = %{version}

%description -n libarchive13
 The libarchive library features:

- Support for a variety of archive and compression formats.
- Robust automatic format detection, including archive/compression combinations such as tar.gz.
- Zero-copy internal architecture for high performance.
- Streaming architecture eliminates all limits on size of archive, limits on entry sizes depend on particular formats.
- Carefully factored code to minimize bloat when programs are statically linked.
- Growing test suite to verify correctness of new ports.
- Works on most POSIX-like systems (including FreeBSD, Linux, Solaris, etc.)
- Supports Windows, including Cygwin, MinGW, and Visual Studio.

%package tools
Summary: libarchive utilities
Requires: %{name} = %{version}

%description tools
The bsdtar and bsdcpio command-line utilities are feature- and performance-competitive with other tar and cpio implementations:

- Reads a variety of formats, including tar, pax, cpio, zip, xar, lha, ar, cab, mtree, rar, and ISO images.
- Writes tar, pax, cpio, zip, xar, ar, ISO, mtree, and shar archives.
- Automatically handles archives compressed with gzip, bzip2, lzip, xz, lzma, or compress.
- Unique format conversion feature.


%package devel
Summary: libarchive development files
Requires: %{name} = %{version}

%description devel
libarchive development files


%prep
%setup -q

%build

%if %{reconf}
autoreconf -fi
%endif

%configure \
  CPPFLAGS='-I%{_includedir}' \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
  LIBS="-lpthread" \
%if %{reconf} == 0
  --host=powerpc-ibm-aix6 \
%endif
  --with-aix-soname=svr4 \
  --enable-posix-regex-lib=libpcreposix \
  --without-lz4 \
  --without-lzo2 \
  --without-nettle \
  --disable-xattr \
  --disable-acl \
  --disable-static \
  --disable-rpath \
  # end

%make_build


%install

%make_install

find %{buildroot} -name \*.la | xargs rm || :

rm %{buildroot}%{_mandir}/man5/cpio.5
rm %{buildroot}%{_mandir}/man5/tar.5

%files -n libarchive13
%defattr(-, qsys, *none)

%{_libdir}/libarchive.so.13

%files tools
%defattr(-, qsys, *none)

%{_bindir}/bsdtar
%{_bindir}/bsdcat
%{_bindir}/bsdcpio

%{_mandir}/man1/bsdcat.1
%{_mandir}/man1/bsdcpio.1
%{_mandir}/man1/bsdtar.1

%{_mandir}/man5/libarchive-formats.5
%{_mandir}/man5/mtree.5

%files devel
%defattr(-, qsys, *none)

%{_includedir}/*
%{_libdir}/*.so

%{_mandir}/man3/archive_entry.3
%{_mandir}/man3/archive_entry_acl.3
%{_mandir}/man3/archive_entry_linkify.3
%{_mandir}/man3/archive_entry_paths.3
%{_mandir}/man3/archive_entry_perms.3
%{_mandir}/man3/archive_entry_stat.3
%{_mandir}/man3/archive_entry_time.3
%{_mandir}/man3/archive_read.3
%{_mandir}/man3/archive_read_add_passphrase.3
%{_mandir}/man3/archive_read_data.3
%{_mandir}/man3/archive_read_disk.3
%{_mandir}/man3/archive_read_extract.3
%{_mandir}/man3/archive_read_filter.3
%{_mandir}/man3/archive_read_format.3
%{_mandir}/man3/archive_read_free.3
%{_mandir}/man3/archive_read_header.3
%{_mandir}/man3/archive_read_new.3
%{_mandir}/man3/archive_read_open.3
%{_mandir}/man3/archive_read_set_options.3
%{_mandir}/man3/archive_util.3
%{_mandir}/man3/archive_write.3
%{_mandir}/man3/archive_write_blocksize.3
%{_mandir}/man3/archive_write_data.3
%{_mandir}/man3/archive_write_disk.3
%{_mandir}/man3/archive_write_filter.3
%{_mandir}/man3/archive_write_finish_entry.3
%{_mandir}/man3/archive_write_format.3
%{_mandir}/man3/archive_write_free.3
%{_mandir}/man3/archive_write_header.3
%{_mandir}/man3/archive_write_new.3
%{_mandir}/man3/archive_write_open.3
%{_mandir}/man3/archive_write_set_options.3
%{_mandir}/man3/archive_write_set_passphrase.3
%{_mandir}/man3/libarchive.3
%{_mandir}/man3/libarchive_changes.3
%{_mandir}/man3/libarchive_internals.3

%{_libdir}/pkgconfig/libarchive.pc


%changelog
